@@ -1,6 +1,7 @@
 from typing import Any, Dict
 
 from .index import BaseIndexDriver
+from ..executors.indexers.cache import DATA_FIELD, CONTENT_HASH_KEY
 
 if False:
     from .. import Document
@@ -10,40 +11,42 @@ if False:
 class BaseCacheDriver(BaseIndexDriver):
     """
     The driver related to :class:`BaseCache`
-
     """
 
     def __init__(self, with_serialization: bool = False, *args, **kwargs):
         """
-
         :param with_serialization: feed serialized doc to the CacheIndexer
         :param args:
         :param kwargs:
         """
         self.with_serialization = with_serialization
         super().__init__(*args, **kwargs)
+        self.field = None
 
     def _apply_all(self, docs: 'DocumentSet', *args, **kwargs) -> None:
+        self.field = self.exec.field
+
         for d in docs:
-            result = self.exec[d.id]
+            data = d.id
+            if self.field == CONTENT_HASH_KEY:
+                data = d.content_hash
+            result = self.exec[data]
             if result is None:
-                self.on_miss(d)
+                self.on_miss(d, data)
             else:
                 self.on_hit(d, result)
 
-    def on_miss(self, doc: 'Document') -> None:
+    def on_miss(self, doc: 'Document', data) -> None:
         """Function to call when doc is missing, the default behavior is add to cache when miss
-
         :param doc: the document in the request but missed in the cache
         """
         if self.with_serialization:
-            self.exec_fn(doc.id, doc.SerializeToString())
+            self.exec_fn(doc.id, doc.SerializeToString(), **{DATA_FIELD: data})
         else:
-            self.exec_fn(doc.id)
+            self.exec_fn(doc.id, **{DATA_FIELD: data})
 
     def on_hit(self, req_doc: 'Document', hit_result: Any) -> None:
         """ Function to call when doc is hit
-
         :param req_doc: the document in the request and hitted in the cache
         :param hit_result: the hit result returned by the cache
         :return:
